@@ -6,7 +6,7 @@ use v5.10;
 use base qw( WebService::LiveJournal::Client );
 
 # ABSTRACT: Interface to the LiveJournal API
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 sub _set_error
 {
@@ -29,7 +29,7 @@ WebService::LiveJournal - Interface to the LiveJournal API
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,9 @@ It is recommended that for any new code that you use the new interface.
 
 =head1 CONSTRUCTOR
 
-=head2 WebService::LiveJournal::Client->new( %options )
+=head2 new
+
+ my $client = WebService::LiveJournal::Client->new( %options )
 
 Connects to a LiveJournal server using the host and user information
 provided by C<%options>.
@@ -157,7 +159,9 @@ fast server mode.
 
 =head1 METHODS
 
-=head2 $client-E<gt>create_event( %options )
+=head2 create_event
+
+ $client->create_event( %options )
 
 Creates a new event and returns it in the form of an instance of
 L<WebService::LiveJournal::Event>.  This does not create the 
@@ -186,7 +190,9 @@ is equivalent to this:
 This method signals an error depending on the interface
 selected by throwing an exception or returning undef.
 
-=head2 $client-E<gt>get_events( $select_type, %query )
+=head2 get_events
+
+ $client->get_events( $select_type, %query )
 
 Selects events from the LiveJournal server.  The actual C<%query>
 parameter requirements depend on the C<$select_type>.
@@ -250,14 +256,19 @@ date of the format C<yyyy-mm-dd hh:mm:ss>
 This method signals an error depending on the interface
 selected by throwing an exception or returning undef.
 
-=head2 $client-E<gt>get_event( $itemid )
+=head2 get_event
+
+ $client->get_event( $itemid )
 
 Given an C<itemid> (the internal LiveJournal identifier for an event).
 
 This method signals an error depending on the interface
 selected by throwing an exception or returning undef.
 
-=head2 $client-E<gt>sync_items( [ last_sync =E<gt> $time ], $cb )
+=head2 sync_items
+
+ $client->sync_items( $cb )
+ $client->sync_items( last_sync => $time, $cb )
 
 Fetch all of the items which have been created/modified since the last sync.
 If C<last_sync =E<gt> $time> is not provided then it will fetch all events.
@@ -324,7 +335,9 @@ return value back into C<sync_items> again.  You can tell
 that C<sync_item> completed without error because the 
 C<$client-E<gt>error> accessor should return a false value.
 
-=head2 $client-E<gt>get_friends( %options )
+=head2 get_friends
+
+ $client->get_friends( %options )
 
 Returns friend information associated with the account with which you are logged in.
 
@@ -350,7 +363,9 @@ If set to a numeric value greater than zero, this mode will only return the numb
 
 =back
 
-=head2 $client-E<gt>get_friend_of( %options )
+=head2 get_friends_of
+
+ $client->get_friend_of( %options )
 
 Returns the list of users that are a friend of the logged in account.
 
@@ -367,19 +382,26 @@ If set to a numeric value greater than zero, this mode will only return the numb
 
 =back
 
-=head2 $client-E<gt>get_friend_groups
+=head2 get_friend_groups
+
+ $client->get_friend_groups
 
 Returns your friend groups.  This comes as an instance of
 L<WebService::LiveJournal::FriendGroupList> that contains
 zero or more instances of L<WebService::LiveJournal::FriendGroup>.
 
-=head2 $client-E<gt>get_user_tags( [ $journal_name ] )
+=head2 get_user_tags
+
+ $client->get_user_tags;
+ $client->get_user_tags( $journal_name );
 
 Fetch the tags associated with the given journal, or the users journal
 if not specified.  This method returns a list of zero or more
 L<WebService::LiveJournal::Tag> objects.
 
-=head2 $client-E<gt>console_command( $command, @arguments )
+=head2 console_command
+
+ $client->console_command( $command, @arguments )
 
 Execute the given console command with the given arguments on the
 LiveJournal server.  Returns the output as a list reference.
@@ -396,7 +418,10 @@ returns:
    [ 'success', "hello world" ],
  ]
 
-=head2 $client-E<gt>batch_console_commands( $command1, $callback, [ $command2, $callback, [ ... ] )
+=head2 batch_console_commands
+
+ $client->batch_console_commands( $command1, $callback);
+ $client->batch_console_commands( $command1, $callback, [ $command2, $callback, [ ... ] );
 
 Execute a list of commands on the LiveJournal server in one request. Each command is a list reference. Each callback 
 associated with each command will be called with the results of that command (in the same format returned by 
@@ -415,12 +440,16 @@ C<console_command> mentioned above, except it is passed in as a list instead of
    },
  );
 
-=head2 $client-E<gt>set_cookie( $key => $value )
+=head2 set_cookie
+
+ $client->set_cookie( $key => $value )
 
 This method allows you to set a cookie for the appropriate security and expiration information.
 You shouldn't need to call it directly, but is available here if necessary.
 
-=head2 $client-E<gt>send_request( $procname, @arguments )
+=head2 send_request
+
+ $client->send_request( $procname, @arguments )
 
 Make a low level request to LiveJournal with the given
 C<$procname> (the rpc procedure name) and C<@arguments>
@@ -432,7 +461,9 @@ On success returns the appropriate L<RPC::XML> type
 This method signals an error depending on the interface
 selected by throwing an exception or returning undef.
 
-=head2 $client-E<gt>send_flat_request( $procname, @arguments )
+=head2 send_flat_request
+
+ $client->send_flat_request( $procname, @arguments )
 
 Sends a low level request to the LiveJournal server using the flat API,
 with the given C<$procname> (the rpc procedure name) and C<@arguments>.
@@ -442,7 +473,9 @@ On success returns the appropriate response.
 This method signals an error depending on the interface
 selected by throwing an exception or returning undef.
 
-=head2 $client-E<gt>error
+=head2 error
+
+ $client->error
 
 Returns the last error.  This just returns
 $WebService::LiveJournal::Client::error, so it
@@ -645,8 +678,6 @@ L<LJ::Simple>
 
 =back
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
